@@ -4,6 +4,36 @@
 
 """
 
+control_version:0.5.5
+blcoklyFile_version:0.2.4
+blockly_version:2.3.0
+更新内容：
+本地化语音转文字库和编程块
+"""
+
+"""
+2020/4/4
+control_version:0.5.4
+blcoklyFile_version:0.2.3
+blockly_version:2.3.0
+更新内容：
+修改了视觉部分，将摄像头分辨率降低到320✖240。但是最后的输出还是放大回了640✖480
+修改了舵机的块
+
+"""
+
+"""
+2022/4/1
+control_version:0.5.3
+blcoklyFile_version:0.2.3
+blockly_version:2.2.1
+更新内容：
+修改了machine_learning的大量内容
+修改了机器学习对应的块
+增加了模版匹配函数
+增加了模版匹配的块
+"""
+"""
 2022/3/27
 control_version:0.5.2
 blcoklyFile_version:0.2.2
@@ -12,17 +42,14 @@ blockly_version:2.2.1
 修改了blocklyFiles的块：硬件控制-->小车控制-->中的第二个块
 增加了屏幕函数
 修改了仿真器的块
-
 """
 """
-
 2022/3/21
 control_version:0.5.1
 blcoklyFile_version:0.2.0
 blockly_version:2.2.1
 更新内容：
 修改了在树莓派不能调用摄像头的bug
-
 """
 """
 2022/3/21
@@ -37,10 +64,8 @@ blockly_version:2.2.1
 5.修改了mediapipe的库和类，包括身体部位检测、手指检测
 6.删除了原来有的人脸检测，换成了mediapipe的
 7.增加了背景图像切换的操作
-
 """
 """
-
 2022/3/13
 control_version:0.4.2
 blcoklyFile_version:0.1.2
@@ -52,13 +77,10 @@ blockly_version:2.2.1
 4、shijue0删除了一个变量self.Type，原本是用来返回图像类型的，现在被上面那个新函数代替。
 5、增加了轮廓检测的块
 6、修改了返回图像类型的块的代码区域的内容
-
 """
 """
-
 2022/3/7
 control_version:0.4.1
 blcoklyFile_version:0.1.1
 blockly_version:2.2.1
-
-"""
+"""
\ No newline at end of file
