@@ -5,29 +5,36 @@ import numpy as np
 from collections import deque
 import math
 from .shijue0 import basicImg
-import mediapipe as mp
 from cvzone.SelfiSegmentationModule import SelfiSegmentation
 import os
-os.environ['TF_CPP_MIN_LOG_LEVEL']='2'
 
 
+os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2'
+
 system_platform = sys.platform
 main_path = '/home/pi/class/'  # 读取和保存文件所用主文件夹
+
 if 'win' in system_platform:
+    import mediapipe as mp
     file_path = os.getcwd()
     # 获取当前文件的位置
     main_path = file_path + '/resources/assets/class/'
+else:
+    try:
+        import mediapipe as mp
+    except ImportError:
+        os.system('sudo pip3 install mediapipe-rpi4')
+
 picture_path = main_path + 'picture/'  # 图片文件夹
 model_path = main_path + 'model/'  # 识别模型文件夹
 d_path = main_path + 'camera_pos/'
 dat_path = main_path + 'data/face_recognize/'
 
 items_num = {0: '0', 1: '1', 2: '2', 3: '3',
-             4: '4', 5: '5', 6: '6', 7: '7', 8: '8', 9:'9'}  # 方向数字指示牌
+             4: '4', 5: '5', 6: '6', 7: '7', 8: '8', 9: '9'}  # 方向数字指示牌
 items_dir = {9: '左转', 10: '右转'}
 
 
-
 class Assist_converse:
     def __init__(self):
         pass
@@ -43,42 +50,32 @@ def new_file(path):
 
 class Img(basicImg):
     def __init__(self):
-
         super(Img, self).__init__()
-
         '''
         人脸识别属性
         '''
         self.ID = ''
         self.model_ID = self.ID
-
         self.data_path = None
         self.save_model_name = None
         self.face_model = model_path + 'face_0.xml'
         self.face_detector = cv2.CascadeClassifier(self.face_model)
-
         self.faces = None
         self.ids = None
         self.face_name = 'none'
-
         self.recognizer = cv2.face.LBPHFaceRecognizer_create()
-
         self.Type = None
-
         '''
         人脸检测属性
         '''
         self.path = ''
         self.cascade = None
-
-
         '''
         戴帽子、口罩属性
         '''
         self.pht = ''
         self.flag_cap = 0
         self.flag_mask = 0
-
         '''
         形状检测属性
         '''
@@ -88,21 +85,19 @@ class Img(basicImg):
         self.cx = 0
         self.cy = 0
         self.radium = 0
-        self.circle_center = [0,0]
+        self.circle_center = [0, 0]
         self.area = 0
         self.length = 0
         self.shape_type = 'None'
         self.draw_or_not = 0
-
         '''
                mediapipe属性
          '''
         self.fingertip = {}
-        self.body_menu={}
+        self.body_menu = {}
         # self.mp_drawing = mp.solutions.drawing_utils
         # self.mp_drawing_styles = mp.solutions.drawing_styles
 
-
     '''
             以下 change_ID、get_data、get_info、train、predict_init、predict函数都是用来进行人脸识别的
             change_ID: 用来获取想要进行人脸注册的人名
@@ -178,7 +173,6 @@ class Img(basicImg):
                 # 获取图片人脸特征
                 faces = self.face_detector.detectMultiScale(img_numpy)
                 # 获取每张图片的id和姓名
-
                 # 预防无面容照片
                 for x, y, w, h in faces:
                     ids.append(im)
@@ -198,11 +192,9 @@ class Img(basicImg):
         print('训练完毕，模型已保存到：', self.save_model_name, '模型名称为：', self.ID)
 
     def predict_init(self, m_name=''):
-
         ret = self.get_info()
         if ret == False:
             return False
-
         model_name = self.save_model_name
         if len(m_name) != 0:
             model_name = model_path + m_name + '.yml'
@@ -232,7 +224,6 @@ class Img(basicImg):
                         self.face_name = str(self.names[ids - 1])
                 except:
                     pass
-
             self.name_windows('face recognize result')
             self.show_image('face recognize result', img)
         except cv2.error:
@@ -254,7 +245,6 @@ class Img(basicImg):
             I.face_detect()
             I.show_image('output')
             I.delay(1)
-
         示例2 戴帽子（戴口罩同理）：
         I = Img()
         I.camera(0)
@@ -265,22 +255,21 @@ class Img(basicImg):
             I.face_cap()
             I.show_image('output')
             I.delay(1)
-
     '''
 
     def face_detect_init(self, model_name):
-        self.mpFaceDetection = mp.solutions.face_detection #人脸识别
+        self.mpFaceDetection = mp.solutions.face_detection  # 人脸识别
         self.mpDraw = mp.solutions.drawing_utils
         self.faceDetection = self.mpFaceDetection.FaceDetection(0.5)
         self.face_data = '没有人'
 
-    def face_detect(self, cool = False, draw = True):
+    def face_detect(self, cool=False, draw=True):
         img_new = self.img.copy()
         imgRGB = cv2.cvtColor(img_new, cv2.COLOR_BGR2RGB)
         self.results = self.faceDetection.process(imgRGB)
         bboxs = []
-        if self.results.detections==None:
-            self.face_data='没有人'
+        if self.results.detections == None:
+            self.face_data = '没有人'
             return img_new, bboxs
         if self.results.detections:
             self.face_data = f'检测到{len(self.results.detections)}个人'
@@ -305,7 +294,6 @@ class Img(basicImg):
                         cv2.line(img_new, (x1, y1), (x1, y1 - 30), (255, 0, 255), 5)
                     else:
                         cv2.rectangle(img_new, bbox, (255, 0, 255), 3)
-
         self.name_windows('face detect result')
         self.show_image('face detect result', img_new)
 
@@ -366,7 +354,6 @@ class Img(basicImg):
         im3 = np.add(im3, mean)
         im3 = np.divide(im3, std)
         img = np.expand_dims(im3, axis=0)
-
         self.model.setInput(img)
         out = self.model.forward()
         e_x = np.exp(out.squeeze() - np.max(out.squeeze()))
@@ -385,10 +372,8 @@ class Img(basicImg):
         # mean = mean[:, np.newaxis, np.newaxis]
         # std = std[:, np.newaxis, np.newaxis]
         self.color_detect_init('red')
-        self.setcolorvalue('red',[173, 43, 46],[180, 255, 255])
-
+        self.setcolorvalue('red', [173, 43, 46], [180, 255, 255])
         self.color_detect()
-
         if self.img_new.all() != self.img.all():
             gray = cv2.cvtColor(self.img_new, cv2.COLOR_BGR2GRAY)
             ret, img_new = cv2.threshold(gray, 0, 255, cv2.THRESH_BINARY + cv2.THRESH_OTSU)
@@ -401,7 +386,6 @@ class Img(basicImg):
             # im3 = np.add(im3, mean)
             # im3 = np.divide(im3, std)
             img = np.expand_dims(im3, axis=0)
-
             self.model.setInput(img)
             out = self.model.forward()
             e_x = np.exp(out.squeeze() - np.max(out.squeeze()))
@@ -418,7 +402,6 @@ class Img(basicImg):
 
     '''
            以下 color_detect_init、set_hsv、getpos、setcolorvalue、color_detect是用来进行颜色检测的
-
         '''
 
     def color_detect_init(self, color):
@@ -427,8 +410,8 @@ class Img(basicImg):
             self.color_list_lower = [0, 142, 104]  # 这是红色的数值
             self.color_list_upper = [10, 255, 255]
         elif color == 'green':
-            self.color_list_lower = [35, 43, 46]
-            self.color_list_upper = [77, 255, 255]
+            self.color_list_lower = [24, 43, 46]
+            self.color_list_upper = [64, 255, 255]
         elif color == 'yellow':
             self.color_list_lower = [26, 43, 46]
             self.color_list_upper = [34, 255, 255]
@@ -453,7 +436,6 @@ class Img(basicImg):
         elif color == 'qing':
             self.color_list_lower = [78, 43, 46]
             self.color_list_upper = [99, 255, 255]
-
         self.colorLower = np.array(self.color_list_lower)  # 这是红色的数值
         self.colorUpper = np.array(self.color_list_upper)
         self.color = color
@@ -495,7 +477,7 @@ class Img(basicImg):
             if self.HSV[y, x][2] > self.Vmax:
                 self.Vmax = self.HSV[y, x][2]
 
-    def setcolorvalue(self, color, color_list_low:list, color_list_up:list):
+    def setcolorvalue(self, color, color_list_low: list, color_list_up: list):
         self.color_list_lower = color_list_low
         self.color_list_upper = color_list_up
         self.colorLower = np.array(self.color_list_lower)  # 这是红色的数值
@@ -521,7 +503,6 @@ class Img(basicImg):
         # 膨胀操作，其实先腐蚀再膨胀的效果是开运算，去除噪点
         mask = cv2.dilate(mask, None, iterations=2)
         cnts = cv2.findContours(mask.copy(), cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_SIMPLE)[-2]
-
         # 初始化识别物体圆形轮廓质心
         center = None
         # 如果存在轮廓
@@ -538,7 +519,10 @@ class Img(basicImg):
                     # self.img_new=frame_bgr
                     self.img_new = frame
                 else:
-                    self.img_new = frame[y + 20:y + h - 20, x + 20:x + w - 20]
+                    self.img_new = frame[y + 5:y + h - 5, x + 5:x + w - 5]
+
+                self.img_new = cv2.resize(self.img_new, dsize=None, fx=2, fy=2,
+                                          interpolation=cv2.INTER_LINEAR)  # 这一行是放大图像变回 640✖480
                 cv2.imshow('result', self.img_new)
                 cv2.waitKey(3)
 
@@ -555,7 +539,6 @@ class Img(basicImg):
             if radius > 5:
                 # img_circle=cv2.circle(self.frame, (int(x), int(y)), int(radius), (0, 255, 255), 2)
                 # cv2.circle(self.frame, center, 5, (0, 0, 255), -1)
-
                 # 把质心添加到pts中，并且是添加到列表左侧
                 self.pts.appendleft(center)
                 # cv2.imshow('color1', self.frame)
@@ -565,7 +548,6 @@ class Img(basicImg):
                 Y = y + h / 2  # 中心点坐标
                 self.distance = ((X - 250) ** 2 + (Y - 250) ** 2) ** 0.5  # 离中心点的距离
                 self.midle = [X, Y]  # 检测后返回红点的中心值
-
         else:  # 如果图像中没有检测到识别物体，则清空pts，图像上不显示轨迹。
             self.pts.clear()
             # cv2.imshow('color2', self.frame)
@@ -573,14 +555,16 @@ class Img(basicImg):
             self.color_data = 'other_color'
             self.midle = [0, 0]  # 中心点坐标
             self.distance = 0  # 离中心点的距离
+
     '''
-    
+
     以下是物体形状检测与识别
-    
+
     '''
+
     def color_mask_init(self, mask_color):
         if mask_color == 'red':
-            self.mask_color_list_lower = [131,56,73]  # 这是红色的数值
+            self.mask_color_list_lower = [131, 56, 73]  # 这是红色的数值
             self.mask_color_list_upper = [180, 255, 255]
         elif mask_color == 'green':
             self.mask_color_list_lower = [18, 45, 97]
@@ -589,8 +573,8 @@ class Img(basicImg):
             self.mask_color_list_lower = [26, 43, 46]
             self.mask_color_list_upper = [34, 255, 255]
         elif mask_color == 'blue':
-            self.mask_color_list_lower = [78,57,50]
-            self.mask_color_list_upper = [141, 255, 255]
+            self.mask_color_list_lower = [92, 56, 139]
+            self.mask_color_list_upper = [102, 255, 255]
         elif mask_color == 'orange':
             self.mask_color_list_lower = [11, 43, 46]
             self.mask_color_list_upper = [25, 255, 255]
@@ -609,7 +593,6 @@ class Img(basicImg):
         elif mask_color == 'qing':
             self.mask_color_list_lower = [78, 43, 46]
             self.mask_color_list_upper = [99, 255, 255]
-
         self.mask_color_lower = np.array(self.mask_color_list_lower)
         self.mask_color_upper = np.array(self.mask_color_list_upper)
 
@@ -627,10 +610,12 @@ class Img(basicImg):
         mask = cv2.erode(mask, None, iterations=2)
         # 膨胀操作，其实先腐蚀再膨胀的效果是开运算，去除噪点
         self.mask_img = cv2.dilate(mask, None, iterations=2)
-        cv2.imshow('mask',self.mask_img)
+        self.mask_img = cv2.resize(self.mask_img, dsize=None, fx=2, fy=2,
+                                   interpolation=cv2.INTER_LINEAR)  # 这一行是放大图像变回 640✖480
+        cv2.imshow('mask', self.mask_img)
         cv2.waitKey(3)
 
-    def circle_detect(self,img):
+    def circle_detect(self, img):
         gaussian = cv2.GaussianBlur(img, (3, 3), 0)
         circles1 = cv2.HoughCircles(gaussian, cv2.HOUGH_GRADIENT, 1, 110, param1=200, param2=35, minRadius=0,
                                     maxRadius=0)
@@ -646,7 +631,7 @@ class Img(basicImg):
             cv2.circle(self.img, self.circle_center, self.radium, (48, 48, 255), 2)
         else:
             self.shape_type = 'None'
-            self.circle_center = [0,0]
+            self.circle_center = [0, 0]
             self.radium = 0
 
     def polygon_detect(self):
@@ -656,11 +641,9 @@ class Img(basicImg):
             # print('c', c)
             x0, y0, w0, h0 = cv2.boundingRect(c)  # 最大面积区域的外接矩形   x,y是左上角的坐标，w,h是矩形的宽和高
             if w0 > 40 and h0 > 40:  # 宽和高大于一定数值的才要。
-
                 # 轮廓逼近
                 epsilon = 0.0115 * cv2.arcLength(c, True)
                 approx = cv2.approxPolyDP(c, epsilon, True)
-
                 # 分析几何形状
                 self.polygon_corners = len(approx)
                 if self.draw_or_not:
@@ -668,27 +651,25 @@ class Img(basicImg):
                     self.circle_center = [int((2 * x1 + w1) / 2), int((2 * y1 + h1) / 2)]
                     self.radium = int(math.sqrt((w1 / 2) ** 2 + (h1 / 2) ** 2) - 15)
                     cv2.circle(self.img, self.circle_center, self.radium, (48, 48, 255), 2)
-
                 # 求解中心位置
                 mm = cv2.moments(c)
                 self.cx = int(mm['m10'] / (mm['m00'] + 1))
                 self.cy = int(mm['m01'] / (mm['m00'] + 1))
-
                 # 计算面积与周长
                 self.length = cv2.arcLength(c, True)
                 self.area = cv2.contourArea(c)
             else:
                 self.radium = 0
-                self.circle_center = [0,0]
+                self.circle_center = [0, 0]
 
-    def shape_detect(self,shape):
+    def shape_detect(self, shape):
         self.color_mask()
         if shape == 'circle':
             mask = self.mask_img
             # gaussian = cv2.GaussianBlur(mask, (3, 3), 0)
             edge = cv2.Canny(mask, 30, 100, apertureSize=3)
             self.circle_detect(edge)
-        if shape in ['triangle','rectangle','polygon']:
+        if shape in ['triangle', 'rectangle', 'polygon']:
             self.polygon_detect()
             if self.polygon_corners == 3 and shape == 'triangle':
                 self.shape_type = "triangle"
@@ -705,26 +686,25 @@ class Img(basicImg):
         self.shape_position()
 
     def shape_analysis(self):
-            self.polygon_detect()
-            if self.polygon_corners == 3:
-                self.shape_type = "triangle"
-            elif 4 <= self.polygon_corners <= 9:
-                self.shape_type = "rectangle"
-            elif self.polygon_corners >= 10:
-                self.shape_type = "polygon"
-            else:
-                self.shape_type = 'None'
+        self.polygon_detect()
+        if self.polygon_corners == 3:
+            self.shape_type = "triangle"
+        elif 4 <= self.polygon_corners <= 9:
+            self.shape_type = "rectangle"
+        elif self.polygon_corners >= 10:
+            self.shape_type = "polygon"
+        else:
+            self.shape_type = 'None'
 
     def shape_position(self):
         center = self.circle_center
         b, a, channels = self.img.shape
-        if 0 < center[0] <= a/3:
+        if 0 < center[0] <= a / 3:
             self.shape_direction_p = 'left'
-        elif a/3 < center[0] < 2*a/3:
+        elif a / 3 < center[0] < 2 * a / 3:
             self.shape_direction_p = 'middle'
-        elif 2*a/3 < center[0] < a:
+        elif 2 * a / 3 < center[0] < a:
             self.shape_direction_p = 'right'
-
         if 0 < center[1] <= b / 3:
             self.shape_direction_s = 'top'
         elif b / 3 < center[1] < 2 * b / 3:
@@ -735,6 +715,7 @@ class Img(basicImg):
     """
     以下为mediapipe的人体姿态交互功能的函数，为保证最大自由度，函数可返回读取的人体关键点数值，其中有些部分的函数的返回值用户可以自行选择。
     """
+
     def finger_init(self):
         self.mpHands = mp.solutions.hands
         self.hands = self.mpHands.Hands()
@@ -747,30 +728,39 @@ class Img(basicImg):
         results = self.hands.process(imgRGB)
         if results.multi_hand_landmarks:
             for id, handlms in enumerate(results.multi_hand_landmarks):
-                self.fingertip["big_finger"+(str(id) if id!=0 else '')]=(int(handlms.landmark[4].x*w),int(handlms.landmark[4].y*h))
-                self.fingertip["fore_finger"+(str(id) if id!=0 else '')] = (int(handlms.landmark[8].x * w), int(handlms.landmark[8].y * h))
-                self.fingertip["middle_finger"+(str(id) if id!=0 else '')] = (int(handlms.landmark[12].x * w), int(handlms.landmark[12].y * h))
-                self.fingertip["ring_finger"+(str(id) if id!=0 else '')] = (int(handlms.landmark[16].x * w), int(handlms.landmark[16].y * h))
-                self.fingertip["little_finger"+(str(id) if id!=0 else '')] = (int(handlms.landmark[20].x * w), int(handlms.landmark[20].y * h))
+                self.fingertip["big_finger" + (str(id) if id != 0 else '')] = (
+                int(handlms.landmark[4].x * w), int(handlms.landmark[4].y * h))
+                self.fingertip["fore_finger" + (str(id) if id != 0 else '')] = (
+                int(handlms.landmark[8].x * w), int(handlms.landmark[8].y * h))
+                self.fingertip["middle_finger" + (str(id) if id != 0 else '')] = (
+                int(handlms.landmark[12].x * w), int(handlms.landmark[12].y * h))
+                self.fingertip["ring_finger" + (str(id) if id != 0 else '')] = (
+                int(handlms.landmark[16].x * w), int(handlms.landmark[16].y * h))
+                self.fingertip["little_finger" + (str(id) if id != 0 else '')] = (
+                int(handlms.landmark[20].x * w), int(handlms.landmark[20].y * h))
             self.mpDraw.draw_landmarks(img_new, handlms, self.mpHands.HAND_CONNECTIONS)
         else:
-            self.fingertip={}
+            self.fingertip = {}
+        img_new = cv2.resize(img_new, dsize=None, fx=2, fy=2, interpolation=cv2.INTER_LINEAR)  # 这一行是放大图像变回 640✖480
         cv2.imshow('finger_detect', img_new)
 
     '''
     手指检测
     '''
+
     def finger_distance(self, tip1='big_finger', tip2='fore_finger'):  # 返回用户选定的两个手骨关键点的距离
         if not bool(self.fingertip):
             return '没有检测到手指'
-        if tip2==tip1:
+        if tip2 == tip1:
             return 0
         else:
-            return math.pow(math.pow(self.fingertip[tip1][0]-self.fingertip[tip2][0],2)+math.pow(self.fingertip[tip1][1]-self.fingertip[tip2][1], 2), 0.5)
+            return math.pow(math.pow(self.fingertip[tip1][0] - self.fingertip[tip2][0], 2) + math.pow(
+                self.fingertip[tip1][1] - self.fingertip[tip2][1], 2), 0.5)
 
     '''
     身体部位检测
     '''
+
     def body_init(self):
         self.mp_pose = mp.solutions.pose
         self.pose = self.mp_pose.Pose()
@@ -784,36 +774,42 @@ class Img(basicImg):
         results = self.pose.process(imgRGB)
         if results.pose_landmarks:
             poselms = results.pose_landmarks.landmark
-            for tur in (('left_wrist',15), ('right_wrist', 16),( 'left_elbow', 13),( 'right_elbow', 14), ('left_ankle', 27), ('right_ankle', 28), ('left_shoulder', 11), ('right_shoulder', 12)):
+            for tur in (
+            ('left_wrist', 15), ('right_wrist', 16), ('left_elbow', 13), ('right_elbow', 14), ('left_ankle', 27),
+            ('right_ankle', 28), ('left_shoulder', 11), ('right_shoulder', 12)):
                 self.body_menu[tur[0]] = (int(poselms[tur[1]].x * w), int(poselms[tur[1]].y * h))
             self.mpDraw.draw_landmarks(img_new, results.pose_landmarks, self.mp_pose.POSE_CONNECTIONS)
+        img_new = cv2.resize(img_new, dsize=None, fx=2, fy=2, interpolation=cv2.INTER_LINEAR)  # 这一行是放大图像变回 640✖480
         cv2.imshow('body_detect', img_new)
 
-    def wrist_mark(self, wrist='left_wrist', mark = 'x'):
+    def wrist_mark(self, wrist='left_wrist', mark='x'):
         if not bool(self.body_menu):
             return '没有检测到人'
-        return self.body_menu[wrist][0 if mark=='x' else 1]
+        return self.body_menu[wrist][0 if mark == 'x' else 1]
 
     def wrist_distance(self, wrist1='left_wrist', wrist2='right_wrist'):
         if not bool(self.body_menu):
             return '没有检测到人'
-        if wrist1==wrist2:
+        if wrist1 == wrist2:
             return 0
-        return math.pow(math.pow(self.body_menu[wrist1][0]-self.body_menu[wrist2][0],2)+math.pow(self.body_menu[wrist1][1]-self.body_menu[wrist2][1], 2), 0.5)
+        return math.pow(math.pow(self.body_menu[wrist1][0] - self.body_menu[wrist2][0], 2) + math.pow(
+            self.body_menu[wrist1][1] - self.body_menu[wrist2][1], 2), 0.5)
 
     '''
     背景切换
     '''
+
     def backCroundChange_init(self):
         self.segmentor = SelfiSegmentation()
 
     def backGroundChange(self, backGroundImageSrc="1.png"):
-        backGroundImageSrc = picture_path+backGroundImageSrc
+        backGroundImageSrc = picture_path + backGroundImageSrc
         img_new = self.img.copy()
         h, w, _ = img_new.shape
         backGroundImage = cv2.resize(cv2.imread(backGroundImageSrc), (w, h), cv2.INTER_AREA)
 
         img_new = self.segmentor.removeBG(img_new, backGroundImage, threshold=0.5)
+        img_new = cv2.resize(img_new, dsize=None, fx=2, fy=2, interpolation=cv2.INTER_LINEAR)  # 这一行是放大图像变回 640✖480
         cv2.imshow('backGroundChange', img_new)
 
     def faceMeshDetect_init(self):
@@ -828,14 +824,59 @@ class Img(basicImg):
         results = self.FaceMesh.process(imgRGB)
         if results.multi_face_landmarks:
             for faceLms in results.multi_face_landmarks:
-                self.mpDraw.draw_landmarks(img_new, faceLms, self.mpFaceMesh.FACEMESH_FACE_OVAL, landmark_drawing_spec=self.drawSpec)
+                self.mpDraw.draw_landmarks(img_new, faceLms, self.mpFaceMesh.FACEMESH_FACE_OVAL,
+                                           landmark_drawing_spec=self.drawSpec)
+        img_new = cv2.resize(img_new, dsize=None, fx=2, fy=2, interpolation=cv2.INTER_LINEAR)  # 这一行是放大图像变回 640✖480
         cv2.imshow('faceMesh', img_new)
 
     def get_shape(self, parameter='width'):
-
         # 用于获取图像的尺寸，并根据用户的选择来返回对应的或长或高或是通道数
-
         h, w, c = self.img.shape
         self.parameter = str(parameter)
         shape = {'height': h, 'width': w, 'channel': c}
-        return shape[self.parameter]
\ No newline at end of file
+        return shape[self.parameter]
+
+    '''
+    模版匹配
+    '''
+
+    def match_template_init(self):
+        self.template = None
+        self.min_val, self.max_val, self.min_loc, self.max_loc = None, None, None, None
+        self.isshow = False
+        templist = []
+        for i in range(0, 9):
+            im3 = cv2.imread(picture_path + 'blue' + str(i) + '.jpg')
+            im3 = cv2.resize(im3, dsize=(99, 116))
+            templist.append(im3)
+
+    def match_template(self, template_name):
+        self.isshow = False
+        self.template = cv2.imread(picture_path + template_name)
+        # print(self.template.shape)
+        self.template = cv2.resize(self.template, (99, 116))
+        result = cv2.matchTemplate(self.img, self.template, cv2.TM_CCOEFF_NORMED)
+        self.min_val, self.max_val, self.min_loc, self.max_loc = cv2.minMaxLoc(result)
+
+    def match_result(self):
+        self.isshow = True
+        w, h = self.template.shape[1], self.template.shape[0]
+        top_left = self.max_loc
+        self.max_loc_topleft = list(self.max_loc)
+        self.max_loc_bottomright = [top_left[0] + w, top_left[1] + h]
+        bottom_right = [top_left[0] + w, top_left[1] + h]
+        self.cut_img = self.img[top_left[1]:top_left[1] + h, top_left[0]: top_left[0] + w]
+        self.cut_img = cv2.resize(self.cut_img, dsize=None, fx=2, fy=2,
+                                  interpolation=cv2.INTER_LINEAR)  # 这一行是放大图像变回 640✖480
+        if self.isshow:
+            cv2.imshow('cut', self.cut_img)
+            cv2.rectangle(self.img, top_left, bottom_right, 255, 2)
+        '''
+    def predict_number_match(self, input):
+        for t in templist:
+            res = cv2.matchTemplate(input, t, cv2.TM_CCOEFF_NORMED)
+            min_val, max_val, min_loc, max_loc = cv2.minMaxLoc(res)
+            score.append(max_val)
+        self.predict = np.argmax(score)
+        self.predict = np.argmax(score)
+        '''
\ No newline at end of file
